@@ -11,6 +11,10 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
+var (
+	cycle *ansi.Cycle = &ansi.Cycle{}
+)
+
 type Engine struct {
 	Config *Config
 	Env    platform.Environment
@@ -57,6 +61,8 @@ func (e *Engine) canWriteRightBlock(rprompt bool) bool {
 }
 
 func (e *Engine) PrintPrimary() string {
+	// cache a pointer to the color cycle
+	cycle = &e.Config.Cycle
 	for _, block := range e.Config.Blocks {
 		e.renderBlock(block)
 	}
@@ -143,17 +149,11 @@ func (e *Engine) getTitleTemplateText() string {
 
 func (e *Engine) renderBlock(block *Block) {
 	defer func() {
-		// Due to a bug in PowerShell, the end of the line needs to be cleared.
-		// If this doesn't happen, the portion after the prompt gets colored in the background
-		// color of the line above the new input line. Clearing the line fixes this,
-		// but can hopefully one day be removed when this is resolved natively.
-		if e.Env.Shell() == shell.PWSH || e.Env.Shell() == shell.PWSH5 {
-			e.write(e.Writer.ClearAfter())
-		}
+		e.write(e.Writer.ClearAfter())
 	}()
 	// when in bash, for rprompt blocks we need to write plain
 	// and wrap in escaped mode or the prompt will not render correctly
-	if e.Env.Shell() == shell.BASH && (block.Type == RPrompt || block.Alignment == Right) {
+	if e.Env.Shell() == shell.BASH && block.Type == RPrompt {
 		block.InitPlain(e.Env, e.Config)
 	} else {
 		block.Init(e.Env, e.Writer)
@@ -208,18 +208,10 @@ func (e *Engine) renderBlock(block *Block) {
 			e.write(text)
 			return
 		}
-		// this can contain ANSI escape sequences
-		writer := e.Writer
-		if e.Env.Shell() == shell.BASH {
-			writer.Init(shell.GENERIC)
-		}
-		prompt := writer.CarriageForward()
-		prompt += writer.GetCursorForRightWrite(length, block.HorizontalOffset)
+		prompt := e.Writer.CarriageForward()
+		prompt += e.Writer.GetCursorForRightWrite(length, block.HorizontalOffset)
 		prompt += text
 		e.currentLineLength = 0
-		if e.Env.Shell() == shell.BASH {
-			prompt = e.Writer.FormatText(prompt)
-		}
 		e.write(prompt)
 	case RPrompt:
 		e.rprompt, e.rpromptLength = block.RenderSegments()
@@ -243,6 +235,8 @@ func (e *Engine) PrintDebug(startTime time.Time, version string) string {
 		duration:   time.Since(titleStartTime),
 	}
 	segmentTimings = append(segmentTimings, segmentTiming)
+	// cache a pointer to the color cycle
+	cycle = &e.Config.Cycle
 	// loop each segments of each blocks
 	for _, block := range e.Config.Blocks {
 		block.Init(e.Env, e.Writer)
