@@ -69,9 +69,6 @@ const (
 	strikethroughReset  = "strikethroughr"
 	color16             = "color16"
 	left                = "left"
-	osc99               = "osc99"
-	osc7                = "osc7"
-	osc51               = "osc51"
 	lineChange          = "linechange"
 	consoleTitle        = "title"
 	link                = "link"
@@ -197,9 +194,6 @@ func (ir *ImageRenderer) Init(config string) {
 		strikethroughReset:  `^(?P<STR>\x1b\[29m)`,
 		color16:             `^(?P<STR>\x1b\[(?P<BC>[349][0-7]|10[0-7]|39)m)`,
 		left:                `^(?P<STR>\x1b\[(\d{1,3})D)`,
-		osc99:               `^(?P<STR>\x1b\]9;9;(.+)\x1b\\)`,
-		osc7:                `^(?P<STR>\x1b\]7;(.+)\x1b\\)`,
-		osc51:               `^(?P<STR>\x1b\]51;A(.+)\x1b\\)`,
 		lineChange:          `^(?P<STR>\x1b\[(\d)[FB])`,
 		consoleTitle:        `^(?P<STR>\x1b\]0;(.+)\007)`,
 		link:                fmt.Sprintf(`^%s`, regex.LINK),
@@ -306,6 +300,8 @@ func (ir *ImageRenderer) cleanContent() {
 	// clean string before render
 	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\x1b[m", "\x1b[0m")
 	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\x1b[K", "")
+	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\x1b[0J", "")
+	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\x1b[27m", "")
 	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\x1b[1F", "")
 	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\x1b8", "")
 	ir.AnsiString = strings.ReplaceAll(ir.AnsiString, "\u2800", " ")
@@ -507,7 +503,7 @@ func (ir *ImageRenderer) shouldPrint() bool {
 		case boldReset, italicReset, underlineReset, overlineReset:
 			ir.style = ""
 			return false
-		case strikethrough, strikethroughReset, left, osc99, osc7, osc51, lineChange, consoleTitle:
+		case strikethrough, strikethroughReset, left, lineChange, consoleTitle:
 			return false
 		case color16:
 			ir.setBase16Color(match[bc])
