@@ -17,7 +17,7 @@ func TestUrl(t *testing.T) {
 		Template    string
 		ShouldError bool
 	}{
-		{Case: "valid url", Expected: "[link](https://ohmyposh.dev)", Template: `{{ url "link" "https://ohmyposh.dev" }}`},
+		{Case: "valid url", Expected: "«link»(https://ohmyposh.dev)", Template: `{{ url "link" "https://ohmyposh.dev" }}`},
 		{Case: "invalid url", Expected: "", Template: `{{ url "link" "Foo" }}`, ShouldError: true},
 	}
 
@@ -48,7 +48,7 @@ func TestPath(t *testing.T) {
 		Expected string
 		Template string
 	}{
-		{Case: "valid path", Expected: "[link](file:/test/test)", Template: `{{ path "link" "/test/test" }}`},
+		{Case: "valid path", Expected: "«link»(file:/test/test)", Template: `{{ path "link" "/test/test" }}`},
 	}
 
 	env := &mock.MockedEnvironment{}
